%Lapse_Rate_DailyNaN.m works on data sets containing NaN values and 
%is used to calculate and plot the lapse rate for a particular day.
%This program uses the file Tair_mean which can be found in Tfiles.mat (or
%created using get_Tmean)

%The data in Tair_mean is as follows (numbers representing ibutton data):
%[year-date; 1; 3; 5; 7; 9; 11; 13; 15; 17;
%19; 21; 23; 25; 27; 29; 33; 35; 37; 
%39; 41; 43]

%List the elevation for each ibutton sensor in the same order as listed
%for d:
e = [364 1073 970 745 703 721 1729 1672 1843 2024 2121 663 593 797 1133 1640 1167 697 695 1222 1516]; 

for j = 251   %Set j = column number for the day you want to plot
    num_sensors = (length(Tair_mean(:,1))) - 1;  %Since row 1 contains the date, we don't want to inclue it
    for i = 1:num_sensors 
       t(i) = Tair_mean(i + 1,j);
    end
    new_num_sensors = length(find(~isnan(t)));

    if num_sensors ~= new_num_sensors   %If there are NaNs for that day, this will eliminate them from the plot and polyfit calculation for lapse rate
        [nan_row, nan_col] = find(isnan(t));
        num_nan = length(nan_col);
        l = 1;
        k = 1;
            for q = 1:new_num_sensors
                col  = nan_col(1,l);
                if k ~= col
                    tt(q) = t(1,k);
                    ee(q) = e(1,k);
                elseif k == col
                    tt(q) = t(1,k + 1);
                    ee(q) = e(1,k + 1);
                    k = k + 1;
                    if l < num_nan
                    l = l + 1;
                    end
                end
                if k <= 6
                    t1 = tt(1,1:q);
                    e1 = ee(1,1:q);
                elseif k >= 7 && k <= 11
                    len = length(t1) + 1;
                    t2 = tt(1,len:q);
                    e2 = ee(1,len:q);
                elseif k >= 12 && k <= 15
                    len = length(t1) + length(t2) + 1;
                    t3 = tt(1,len:q);
                    e3 = ee(1,len:q);
                elseif k >=16 && k <= 21
                    len = length(t1) + length(t2) + length(t3) + 1;
                    t4 = tt(1,len:q);
                    e4 = ee(1,len:q);
                end
                k = k + 1;
            end
    p = polyfit(tt,ee,1);
    lapse_rate(j) = roundn((1000/(p(1))),-1);
    f = polyval(p,tt);
    plot(t1,e1,'o',t2,e2,'x',t3,e3,'square',t4,e4,'^',tt,f,'-')
    else

    p = polyfit(t,e,1);
    lapse_rate(j) = roundn((1000/(p(1))),-1);
    f = polyval(p,t);
    plot(t(1,1:6),e(1,1:6),'o',t(1,7:11),e(1,7:11),'x',t(1,12:15),e(1,12:15),'square',t(1,16:21),e(1,16:21),'^',t,f,'-')
    end
    

    hold on
    ylabel('Elevation in meters')
    xlabel(['Average Temperature in ' setstr(176) 'C'])
    legend('Thunder Creek','Maple Pass','West Slope Campgrounds', 'East Slope Campgounds',['Lapse Rate = ' num2str(roundn((1000/(p(1))),-1)), setstr(176) 'C per km'],'location','so')
    title(['Daily Lapse Rate for ' num2str(Tair_mean(1,j))])
    hold off
end

display ('Done')
clear lapse_rate num_sensors e new_num_sensors num_nan q t tt t1 t2 t3 t4 col e1 e2 e3 e4 ee f i j k l len nan_row nan_col p
